﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// 此例程是控制采集卡模拟输入通道连续采集
// 此例程适用型号：
// PCI-225x
// PCI-3xxx
// PCI-5xxx

namespace ai_continuous
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            uint i;
            int DevIndex = 0;
            float[] AiValue = new float[8000];
            uint AiFifoUsdw = 0;

            // 打开设备
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // 设置 Ai 接线方式为 RSE
            rst = SetAiConnectType(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 设置 Ai 采集通道选择
            // 此处选择 ai 0 ~ ai 7，一共 8 通道
            rst = SetAiChannelSellect(DevIndex, 0x00ff);

            // 设置 Ai 采集模式为 连续采集
            rst = SetAiSampleMode(DevIndex, 2);
            if (rst < 0) { return rst; }

            // 设置 Ai 采样周期，10000ns，即 100kS/s
            rst = SetAiSamplePeriod(DevIndex, 10000);
            if (rst < 0) { return rst; }

            // 设置 Ai 量程 1。
            // 对于 PCI-3000 系列，此处将通道 0 ~ 7 均设置为量程 1。
            // 对于 PCI-225x/5000 系列，不需要循环设置 8 次，1 次即可。
            for (i = 0; i < 8; i++)
            {
                rst = SetAiRange(DevIndex, 1, i);
                if (rst < 0) { return rst; }
            }

            // 设置 Ai 触发源，软件触发
            rst = SetAiTrigSource(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 设置 Ai 准备完成，AiReady
            rst = AiReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 发出 Ai 软件触发命令
            rst = SetAiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 读取 Ai 连续采集得到的数据
            // 此处每通道每次读取 1000 点，前面开启了 8 通道
            // 每次一共读取 80000 点，存放于 AiValue 中
            // AiValue[0] ~ AiValue[999] 是通道 ai 0 的数据
            // AiValue[1000] ~ AiValue[1999] 是通道 ai 1 的数据
            // AiValue[2000] ~ AiValue[2999] 是通道 ai 2 的数据
            // AiValue[3000] ~ AiValue[3999] 是通道 ai 3 的数据
            // AiValue[4000] ~ AiValue[4999] 是通道 ai 4 的数据
            // AiValue[5000] ~ AiValue[5999] 是通道 ai 5 的数据
            // AiValue[6000] ~ AiValue[6999] 是通道 ai 6 的数据
            // AiValue[7000] ~ AiValue[7999] 是通道 ai 7 的数据
            // 连续无间断采集数据，只需要循环调用 GetAiData 这个函数，
            // 得到的数据即是连续无间断采集得到的数据，此处只循环 10 次作为范例
            for (i = 0; i < 10; i++)
            {
                rst = GetAiData(DevIndex, 1000, AiValue, ref AiFifoUsdw, 2000);
                if (rst < 0) { return rst; }
                Console.WriteLine("Call GetAiData times: {0}", i);
            }

            // 清除 Ai 软件触发标志
            rst = ClearAiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 清除 Ai 准备完成标志
            rst = AiReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            rst = CloseDevice(DevIndex);
            return rst;
        }
    }
}
