﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

using static Spcidevdll;

// 此例程控制采集卡输出无限不循环的模拟任意波信号。
// 此例程适用型号：
// PCI-2253
// PCI-31xx

namespace ao_waveform_infinite_non_circulation
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i, j;
            float WaveData;
            Random rd = new Random();

            // 打开设备
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // 清空 Ao 0 波形 FIFO
            rst = ClearAoFifo(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 输出为 无限不循环 模式
            rst = SetAoMode(DevIndex, 0, 2);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 输出采样率
            // 此处设置为 100000ns，即 10kS/s
            rst = SetAoSamplePeriod(DevIndex, 0, 100000);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 触发源，Ao 0 软件触发
            rst = SetAoTrigSource(DevIndex, 0, 2);
            if (rst < 0) { return rst; }

            // 先发送 1000 点波形数据到硬件中
            for (i = 0; i < 1000; i++)
            {
                WaveData = (float)rd.Next(0, 100) / (float)100;
                rst = SetAoFifo(DevIndex, 0, WaveData);
                if (rst < 0) { return rst; }
            }

            // 设置 Ao 准备完成，AoReady
            rst = AoReady(DevIndex, 0, 1);
            if (rst < 0) { return rst; }

            // 发出 Ao 0 软件触发命令
            rst = SetAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 开始发送不循环的波形数据到硬件
            // 此处仅发送 10 次作为范例
            for (i = 0; i < 10; i++)
            {
                // 再发送 1000 点波形数据到硬件中
                for (j = 0; j < 1000; j++)
                {
                    WaveData = (float)rd.Next(0, 100) / (float)100;
                    rst = SetAoFifo(DevIndex, 0, WaveData);
                    if (rst < 0) { return rst; }
                }

                // 每隔 100ms 发送 1000 点波形数据到硬件中
                // 保证硬件 FIFO 中有足够的数据，但又不溢出
                Thread.Sleep(100);
            }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // 清除 Ao 0 软件触发标志
            rst = ClearAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 清除 Ao 0 准备完成标志
            rst = AoReady(DevIndex, 0, 0);
            if (rst < 0) { return rst; }

            // 关闭设备
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}
