﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// 此例程控制采集卡模拟输出通道，输出指定次数的任意波信号。
// 此例程适用型号：
// PCI-2253
// PCI-31xx

namespace ao_waveform_n_cycle
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i;
            float[] WaveData = new float[100];

            // 打开设备
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // 清空 Ao 0 波形 FIFO
            rst = ClearAoFifo(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 输出为 n-cycle 模式
            rst = SetAoMode(DevIndex, 0, 1);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 输出采样率
            // 此处设置为 100000ns，即 10kS/s
            rst = SetAoSamplePeriod(DevIndex, 0, 100000);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 输出波形次数
            // 此处输出 10 次。如果设置为 0，表示无限循环输出
            rst = SetAoNCycleCount(DevIndex, 0, 10);
            if (rst < 0) { return rst; }

            // 设置 Ao 0 触发源，Ao 0 软件触发
            rst = SetAoTrigSource(DevIndex, 0, 2);
            if (rst < 0) { return rst; }

            // 生成 100 点的波形数据
            for (i = 0; i < 100; i++)
            {
                WaveData[i] = (((float)i) / 100) * 5;
            }

            // 设置 Ao 0 波形数据
            // 将 100 个点的波形数据写入到硬件
            for (i = 0; i < 100; i++)
            {
                rst = SetAoFifo(DevIndex, 0, WaveData[i]);
                if (rst < 0) { return rst; }
            }

            // 设置 Ao 准备完成，AoReady
            rst = AoReady(DevIndex, 0, 1);
            if (rst < 0) { return rst; }

            // 发出 Ao 0 软件触发命令
            rst = SetAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // 清除 Ao 0 软件触发标志
            rst = ClearAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 清除 Ao 0 准备完成标志
            rst = AoReady(DevIndex, 0, 0);
            if (rst < 0) { return rst; }

            // 关闭设备
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}
