﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// 此例程是控制采集卡数字输入通道单次采集，需要设定每次每通道采集点数。
// 此例程适用型号：
// PCI-1132
// PCI-1316
// PCI-225x
// PCI-3xxx
// PCI-5xxx

namespace di_oneshot
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            uint[] DiValue = new uint[1000];
            uint DiFifoUsdw = 0;

            // 打开设备
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // 设置数字 I/O 方向
            // 由于 PCI-225x/3000/5000 的数字 I/O 可以设置为输入或者输出
            // 此处全部设置为输入
            // 其他数字 I/O 不支持设置的型号可以不用设置
            rst = SetDioDir(DevIndex, 0xffffffff);
            if (rst < 0) { return rst; }

            // 设置 Di 灵敏度
            rst = SetDiSensitivity(DevIndex, 20000);
            if (rst < 0) { return rst; }

            // 设置 Di 采集模式为 OneShot
            rst = SetDiSampleMode(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 设置 Di 采样周期，10000ns，即 100kS/s
            rst = SetDiSamplePeriod(DevIndex, 10000);
            if (rst < 0) { return rst; }

            // 设置 Di OneShot 点数，采集 1000 点
            rst = SetDiOneShotCount(DevIndex, 1000);
            if (rst < 0) { return rst; }

            // 设置 Di 触发源，Di 软件触发
            rst = SetDiTrigSource(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 设置 Di 准备完成，DiReady
            rst = DiReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 发出 Di 软件触发命令
            rst = SetDiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 读取 Di OneShot 得到的数据
            rst = GetDiData(DevIndex, 1000, DiValue, ref DiFifoUsdw, 2000);
            if (rst < 0) { return rst; }

            Console.WriteLine("GetDiData Success.\n");

            // 清除 Di 软件触发标志
            rst = ClearDiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 清除 Di 准备完成标志
            rst = DiReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 关闭设备
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}
