﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

using static Spcidevdll;

// 此例程控制采集卡输出无限不循环的数字任意波信号。
// 此例程适用型号：
// PCI-1232
// PCI-1316
// PCI-225x
// PCI-3xxx

namespace do_waveform_infinite_non_circulation
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i, j;
            uint WaveData;
            Random rd = new Random();

            // 打开设备
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // 设置数字 I/O 方向
            // 此处将所有的数字 I/O 通道设置为输出
            // 由于 PCI-225x/3000/5000 的数字 I/O 可以设置为输入或者输出
            // 此处全部设置为输入
            // 其他数字 I/O 不支持设置的型号可以不用设置
            rst = SetDioDir(DevIndex, 0x00000000);
            if (rst < 0) { return rst; }

            // 清空 Do 波形 FIFO
            rst = ClearDoFifo(DevIndex);
            if (rst < 0) { return rst; }

            // 设置 Do 输出为 无限不循环模式
            rst = SetDoMode(DevIndex, 2);
            if (rst < 0) { return rst; }

            // 设置 Do 输出采样率
            // 此处设置为 100000ns，即 10kS/s
            rst = SetDoSamplePeriod(DevIndex, 100000);
            if (rst < 0) { return rst; }

            // 设置 Do 触发源，Do 软件触发
            rst = SetDoTrigSource(DevIndex, 18);
            if (rst < 0) { return rst; }

            // 先发送 1000 点波形数据到硬件中
            for (i = 0; i < 1000; i++)
            {
                WaveData = (uint)rd.Next();
                rst = SetAoFifo(DevIndex, 0, WaveData);
                if (rst < 0) { return rst; }
            }

            // 设置 Do 准备完成，DoReady
            rst = DoReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 发出 Do 软件触发命令
            rst = SetDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 开始发送不循环的波形数据到硬件
            // 此处仅发送 10 次作为范例
            for (i = 0; i < 10; i++)
            {
                // 再发送 1000 点波形数据到硬件中
                for (j = 0; j < 1000; j++)
                {
                    WaveData = (uint)rd.Next();
                    rst = SetDoFifo(DevIndex, WaveData);
                    if (rst < 0) { return rst; }
                }

                // 每隔 100ms 发送 1000 点波形数据到硬件中
                // 保证硬件 FIFO 中有足够的数据，但又不溢出
                Thread.Sleep(100);
            }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // 清除 Do 软件触发标志
            rst = ClearDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 清除 Do 准备完成标志
            rst = DoReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 关闭设备
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}
