﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// 此例程控制采集卡数字输出通道，输出指定次数的任意波信号。
// 此例程适用型号：
// PCI-1232
// PCI-1316
// PCI-225x
// PCI-3xxx

namespace do_waveform_n_cycle
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i;
            uint[] WaveData = new uint[100];
            Random rd = new Random();

            // 打开设备
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // 设置数字 I/O 方向
            // 此处将所有的数字 I/O 通道设置为输出
            // 由于 PCI-225x/3000/5000 的数字 I/O 可以设置为输入或者输出
            // 此处全部设置为输入
            // 其他数字 I/O 不支持设置的型号可以不用设置
            rst = SetDioDir(DevIndex, 0x00000000);
            if (rst < 0) { return rst; }

            // 清空 Do 波形 FIFO
            rst = ClearDoFifo(DevIndex);
            if (rst < 0) { return rst; }

            // 设置 Do 输出为 n-cycle 模式
            rst = SetDoMode(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 设置 Do 输出采样率
            // 此处设置为 100000ns，即 10kS/s
            rst = SetDoSamplePeriod(DevIndex, 100000);
            if (rst < 0) { return rst; }

            // 设置 Do 输出波形次数
            // 此处输出 10 次。如果设置为 0，表示无限循环输出
            rst = SetDoNCycleCount(DevIndex, 10);
            if (rst < 0) { return rst; }

            // 设置 Do 触发源，Do 软件触发
            rst = SetDoTrigSource(DevIndex, 18);
            if (rst < 0) { return rst; }

            // 生成 100 点的波形数据
            for (i = 0; i < 100; i++)
            {
                WaveData[i] = (uint)rd.Next();
            }

            // 设置 Do 波形数据
            // 将 100 个点的波形数据写入到硬件
            for (i = 0; i < 100; i++)
            {
                rst = SetDoFifo(DevIndex, WaveData[i]);
                if (rst < 0) { return rst; }
            }

            // 设置 Do 准备完成，DoReady
            rst = DoReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // 发出 Do 软件触发命令
            rst = SetDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // 清除 Do 软件触发标志
            rst = ClearDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // 清除 Do 准备完成标志
            rst = DoReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // 关闭设备
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}
